==> SemiParBIVProbit_3.2-9.tar.gz: SemiParBIVProbit/man/adjCov.Rd <==
\name{adjCov}
\alias{adjCov}

\title{Adjustment for the covariance matrix of the parameter estimates from a fitted SemiParBIVProbit model}

\description{ 

\code{adjCov} can be used to adjust the covariance matrix of a fitted \code{SemiParBIVProbit} object.}


\usage{

adjCov(object, id)

}

\arguments{ 

\item{object}{A fitted \code{SemiParBIVProbit} object as produced by \code{SemiParBIVProbit()}.}
 
\item{id}{Cluster identifier.} 




}


\details{

This adjustment can be made when dealing with clustered data and the cluster structure is neglected when fitting the model. The basic idea is that 
the model is fitted as though observations were independent, and subsequently adjust the covariance matrix of the parameter estimates. Using the
terminology of Liang and Zeger (1986), this would correspond to using an independence structure within 
the context of generalized estimating equations. The parameter estimators are still consistent but are inefficient as compared
to a model which accounts for the correct cluster dependence structure. The covariance matrix of the independence estimators can be adjusted 
as described Liang and Zeger (1986, Section 2). 

}



\value{

This function returns a fitted \code{SemiParBIVProbit} object which is identical to that supplied in \code{adjCov} but with adjusted covariance matrix.


}



\section{WARNINGS}{

This correction may not be appropriate for models that require the use of penalties in fitting.

} 


\author{

Maintainer: Giampiero Marra \email{giampiero.marra@ucl.ac.uk}

}




\references{

Liang K.-Y. and Zeger S. (1986), Longitudinal Data Analysis Using Generalized Linear Models. \emph{Biometrika}, 73(1), 13-22.

}




\seealso{
\code{\link{SemiParBIVProbit-package}}, \code{\link{SemiParBIVProbit}}, \code{\link{summary.SemiParBIVProbit}}  
}


\keyword{covariance matrix adjustment}

==> SemiParBIVProbit_3.2-13.2.tar.gz: SemiParBIVProbit/man/adjCov.Rd <==
\name{adjCov}
\alias{adjCov}

\title{Adjustment for the covariance matrix from a fitted SemiParBIVProbit model}

\description{ 

\code{adjCov} can be used to adjust the covariance matrix of a fitted \code{SemiParBIVProbit} object.}


\usage{

adjCov(object, id)

}

\arguments{ 

\item{object}{A fitted \code{SemiParBIVProbit} object as produced by \code{SemiParBIVProbit()}.}
 
\item{id}{Cluster identifier.} 




}


\details{

This adjustment can be made when dealing with clustered data and the cluster structure is neglected when fitting the model. The basic idea is that 
the model is fitted as though observations were independent, and subsequently adjust the covariance matrix of the parameter estimates. Using the
terminology of Liang and Zeger (1986), this would correspond to using an independence structure within 
the context of generalized estimating equations. The parameter estimators are still consistent but are inefficient as compared
to a model which accounts for the correct cluster dependence structure. The covariance matrix of the independence estimators can be adjusted 
as described Liang and Zeger (1986, Section 2). 

}



\value{

This function returns a fitted \code{SemiParBIVProbit} object which is identical to that supplied in \code{adjCov} but with adjusted covariance matrix.


}



\section{WARNINGS}{

This correction may not be appropriate for models that require the use of penalties in fitting.

} 


\author{

Maintainer: Giampiero Marra \email{giampiero.marra@ucl.ac.uk}

}




\references{

Liang K.-Y. and Zeger S. (1986), Longitudinal Data Analysis Using Generalized Linear Models. \emph{Biometrika}, 73(1), 13-22.

}




\seealso{
\code{\link{SemiParBIVProbit-package}}, \code{\link{SemiParBIVProbit}}, \code{\link{summary.SemiParBIVProbit}}  
}


\keyword{covariance matrix adjustment}
